==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard.oxapi/src/com/openexchange/guard/oxapi/pooling/internal/HttpConnectionPoolServiceImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.oxapi.pooling.internal;

import org.apache.http.client.HttpClient;
import com.openexchange.exception.OXException;
import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
import com.openexchange.guard.oxapi.pooling.HttpPoolingStats;

/**
 * Service providing access to a set of connection pools
 */
public class HttpConnectionPoolServiceImpl implements HttpConnectionPoolService {

    private static ConnectionPool cookielessPool;
    private static ConnectionPool cookiePool;
    private static HttpPoolingStats stats;

    /**
     * Initializes all connection pools
     * @throws OXException 
     */
    public HttpConnectionPoolServiceImpl() throws OXException {
        cookielessPool = new ConnectionPool("User Auth", ConnectionPool.CookieHandlingMode.CookieHandligDissabled);
        cookiePool = new ConnectionPool("API", ConnectionPool.CookieHandlingMode.CookieHandlingEnabled);
        stats = new SummarizedHttpPoolingStats(cookielessPool.getConncetionManager().getTotalStats(),
            cookiePool.getConncetionManager().getTotalStats());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#closeAll()
     */
    @Override
    public void closeAll() {
        cookielessPool.close();
        cookiePool.close();
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#getCookielessClient()
     */
    @Override
    public HttpClient getCookielessClient() {
        return cookielessPool.getHttpClient();
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#getClient()
     */
    @Override
    public HttpClient getClient() {
        return cookiePool.getHttpClient();
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#getStats()
     */
    @Override
    public HttpPoolingStats getStats() {
        return stats;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#reset()
     */
    @Override
    public void reset() {
        cookielessPool.reset();
        cookiePool.reset();
    }
}

==> open-xchange-guard_2.10.5.orig.tar.bz2: open-xchange-guard-2.10.5/com.openexchange.guard.oxapi/src/com/openexchange/guard/oxapi/pooling/internal/HttpConnectionPoolServiceImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.oxapi.pooling.internal;

import org.apache.http.client.HttpClient;
import com.openexchange.exception.OXException;
import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
import com.openexchange.guard.oxapi.pooling.HttpPoolingStats;

/**
 * Service providing access to a set of connection pools
 */
public class HttpConnectionPoolServiceImpl implements HttpConnectionPoolService {

    private static ConnectionPool cookielessPool;
    private static ConnectionPool cookiePool;
    private static HttpPoolingStats stats;

    /**
     * Initializes all connection pools
     * @throws OXException
     */
    public HttpConnectionPoolServiceImpl() throws OXException {
        cookielessPool = new ConnectionPool("User Auth", ConnectionPool.CookieHandlingMode.CookieHandligDissabled);
        cookiePool = new ConnectionPool("API", ConnectionPool.CookieHandlingMode.CookieHandlingEnabled);
        stats = new SummarizedHttpPoolingStats(cookielessPool.getPoolControl().getTotalStats(),
            cookiePool.getPoolControl().getTotalStats());
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#closeAll()
     */
    @Override
    public void closeAll() {
        cookielessPool.close();
        cookiePool.close();
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#getCookielessClient()
     */
    @Override
    public HttpClient getCookielessClient() {
        return cookielessPool.getHttpClient();
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#getClient()
     */
    @Override
    public HttpClient getClient() {
        return cookiePool.getHttpClient();
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#getStats()
     */
    @Override
    public HttpPoolingStats getStats() {
        return stats;
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.guard.server.connectionPooling.HttpConnectionPoolService#reset()
     */
    @Override
    public void reset() {
        cookielessPool.reset();
        cookiePool.reset();
    }
}
